# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bstock.proto\"4\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xae\x01\n\x07Request\x12\x12\n\nstock_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63ompany_code\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x04 \x01(\t\x12\x0c\n\x04post\x18\x05 \x01(\t\x12\x0f\n\x07var_num\x18\x06 \x01(\x05\x12\x10\n\x08time_str\x18\x07 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\"-\n\x05Reply\x12\x0b\n\x03txt\x18\x01 \x01(\t\x12\x17\n\x06status\x18\x02 \x01(\x0b\x32\x07.Status2\xcb\x08\n\x08StockInf\x12*\n\x14get_stock_price_tick\x12\x08.Request\x1a\x06.Reply\"\x00\x12)\n\x13get_stock_price_day\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_company_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12*\n\x14get_industry_concept\x12\x08.Request\x1a\x06.Reply\"\x00\x12\'\n\x11get_company_alias\x12\x08.Request\x1a\x06.Reply\"\x00\x12-\n\x17get_chairman_supervisor\x12\x08.Request\x1a\x06.Reply\"\x00\x12%\n\x0fget_stockholder\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_subcompany\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_trade_date\x12\x08.Request\x1a\x06.Reply\"\x00\x12*\n\x14get_market_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12,\n\x16get_industry_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12+\n\x15get_concept_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12%\n\x0fget_entity_role\x12\x08.Request\x1a\x06.Reply\"\x00\x12(\n\x12get_financial_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_total_shares\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_company_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_title_code\x12\x08.Request\x1a\x06.Reply\"\x00\x12/\n\x19get_actual_control_person\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_code_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12-\n\x17get_detail_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x33\n\x1dget_multi_market_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x32\n\x1cget_main_market_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x33\n\x1dget_market_info_by_stock_code\x12\x08.Request\x1a\x06.Reply\"\x00\x12+\n\x15get_company_role_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12(\n\x12get_infos_by_terms\x12\x08.Request\x1a\x06.Reply\"\x00\x62\x06proto3')
)




_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Status.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='Status.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='Status.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=67,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stock_code', full_name='Request.stock_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_code', full_name='Request.company_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='Request.start_date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='Request.end_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='post', full_name='Request.post', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_num', full_name='Request.var_num', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_str', full_name='Request.time_str', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_name', full_name='Request.entity_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Request.title', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=244,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txt', full_name='Reply.txt', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='Reply.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=291,
)

_REPLY.fields_by_name['status'].message_type = _STATUS
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Status)
  })
_sym_db.RegisterMessage(Status)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Request)
  })
_sym_db.RegisterMessage(Request)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Reply)
  })
_sym_db.RegisterMessage(Reply)



_STOCKINF = _descriptor.ServiceDescriptor(
  name='StockInf',
  full_name='StockInf',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=294,
  serialized_end=1393,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_stock_price_tick',
    full_name='StockInf.get_stock_price_tick',
    index=0,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_stock_price_day',
    full_name='StockInf.get_stock_price_day',
    index=1,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_info',
    full_name='StockInf.get_company_info',
    index=2,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_industry_concept',
    full_name='StockInf.get_industry_concept',
    index=3,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_alias',
    full_name='StockInf.get_company_alias',
    index=4,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_chairman_supervisor',
    full_name='StockInf.get_chairman_supervisor',
    index=5,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_stockholder',
    full_name='StockInf.get_stockholder',
    index=6,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_subcompany',
    full_name='StockInf.get_subcompany',
    index=7,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_trade_date',
    full_name='StockInf.get_trade_date',
    index=8,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_market_rise_fall',
    full_name='StockInf.get_market_rise_fall',
    index=9,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_industry_rise_fall',
    full_name='StockInf.get_industry_rise_fall',
    index=10,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_concept_rise_fall',
    full_name='StockInf.get_concept_rise_fall',
    index=11,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_entity_role',
    full_name='StockInf.get_entity_role',
    index=12,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_financial_info',
    full_name='StockInf.get_financial_info',
    index=13,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_total_shares',
    full_name='StockInf.get_total_shares',
    index=14,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_name',
    full_name='StockInf.get_company_name',
    index=15,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_title_code',
    full_name='StockInf.get_title_code',
    index=16,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_actual_control_person',
    full_name='StockInf.get_actual_control_person',
    index=17,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_code_by_name',
    full_name='StockInf.get_code_by_name',
    index=18,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_detail_info_by_name',
    full_name='StockInf.get_detail_info_by_name',
    index=19,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_multi_market_info_by_name',
    full_name='StockInf.get_multi_market_info_by_name',
    index=20,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_main_market_info_by_name',
    full_name='StockInf.get_main_market_info_by_name',
    index=21,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_market_info_by_stock_code',
    full_name='StockInf.get_market_info_by_stock_code',
    index=22,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_role_info',
    full_name='StockInf.get_company_role_info',
    index=23,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_infos_by_terms',
    full_name='StockInf.get_infos_by_terms',
    index=24,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STOCKINF)

DESCRIPTOR.services_by_name['StockInf'] = _STOCKINF

# @@protoc_insertion_point(module_scope)
